# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKTransformPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkScaleSkewVersor3DTransformPython
else:
    import _itkScaleSkewVersor3DTransformPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkArray2DPython
import itk.itkVersorRigid3DTransformPython
import itk.itkVersorTransformPython
import itk.itkRigid3DTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVariableLengthVectorPython
import itk.itkVersorPython

def itkScaleSkewVersor3DTransformD_New():
    return itkScaleSkewVersor3DTransformD.New()

class itkScaleSkewVersor3DTransformD(itk.itkVersorRigid3DTransformPython.itkVersorRigid3DTransformD):
    r"""Proxy of C++ itkScaleSkewVersor3DTransformD class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScaleSkewVersor3DTransformD_Pointer"""
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScaleSkewVersor3DTransformD_Pointer"""
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_Clone(self)

    def SetMatrix(self, *args):
        r"""
        SetMatrix(self, matrix)

        Parameters
        ----------
        matrix: itkMatrixD33 const &

        SetMatrix(self, matrix, tolerance)

        Parameters
        ----------
        matrix: itkMatrixD33 const &
        tolerance: double const

        """
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_SetMatrix(self, *args)

    def SetScale(self, scale):
        r"""
        SetScale(self, scale)

        Parameters
        ----------
        scale: itkVectorD3 const &

        """
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_SetScale(self, scale)

    def GetScale(self):
        r"""GetScale(self) -> itkVectorD3"""
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_GetScale(self)

    def SetSkew(self, skew):
        r"""
        SetSkew(self, skew)

        Parameters
        ----------
        skew: itkVectorD6 const &

        """
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_SetSkew(self, skew)

    def GetSkew(self):
        r"""GetSkew(self) -> itkVectorD6"""
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_GetSkew(self)
    __swig_destroy__ = _itkScaleSkewVersor3DTransformPython.delete_itkScaleSkewVersor3DTransformD

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScaleSkewVersor3DTransformD

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScaleSkewVersor3DTransformD

        Create a new object of the class itkScaleSkewVersor3DTransformD and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScaleSkewVersor3DTransformD.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScaleSkewVersor3DTransformD.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScaleSkewVersor3DTransformD.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScaleSkewVersor3DTransformD in _itkScaleSkewVersor3DTransformPython:
_itkScaleSkewVersor3DTransformPython.itkScaleSkewVersor3DTransformD_swigregister(itkScaleSkewVersor3DTransformD)

